@@ -30,6 +30,13 @@ static const gchar * translater = "Yadickson Soto <yadickson@gmail.com>";
 
 static GladeXML * xml = NULL;
 static bool edit = false;
+std::string configFile;
+
+enum GrowIcons
+{
+    GROW_NORMAL,
+    GROW_INVERTED
+};
 
 enum Positions
 {
@@ -194,7 +201,7 @@ void set_comboboxs()
 
 void set_config()
 {
-    Config config;
+    Config config;    
     std::list <App *> list = config.getAppList();
 
     if (list.size() == 0) return;
@@ -268,6 +275,61 @@ void set_config_states(std::string command)
         }
     }
 
+    OptParser tmpoptparser(argc, argv);
+
+    if ( tmpoptparser.isSet( CONFIG ) )
+    {
+       configFile = tmpoptparser.getArg( CONFIG );
+       Config config;
+       config.setFile (configFile);
+       config.getAppList ();
+
+        std::list<App *> list = config.getAppList();
+        std::list<App *>::iterator it;
+        App *p;
+
+        if (list.size() != 0)
+        {
+            it = list.begin();
+            p = (*it);
+        }
+        else
+        {
+            throw _("Configuration empty.");
+        }
+
+        command = p->getCommand();
+        delete p;
+        
+        if (command.empty())
+        {
+            command = PACKAGE_NAME" "DEFAULT_ARGV;
+        }
+
+        if (argc <= 1 || tmpoptparser.isSet( CONFIG ))
+        {
+            std::list<std::string> list;
+            Utils util;
+            list = util.split ( command, " " );
+            argc = list.size();
+
+            if (argc > 1)
+            {
+                if (argc > 0) delete[] argv;
+                std::list<std::string>::iterator ac;
+                argv = new char * [argc + 1];
+                int i = 0;
+
+                for (ac = list.begin();ac != list.end();ac++, i++)
+                {
+                    argv[i] = strdup((*ac).c_str());
+                }
+
+                argv[argc] = NULL;
+            }
+        }
+    }
+
     OptParser opt(argc, argv);
 
     if(opt.isSet(BPRESS))
@@ -308,6 +370,11 @@ void set_config_states(std::string command)
         else if (pos == "top-right") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_TOP_RIGHT);
         else /*if (pos == "right")*/ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_RIGHT);
     }
+    if(opt.isSet(GROW))
+    {
+        checkbutton = glade_xml_get_widget (xml, "checkbutton_grow");
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
+    }
     if(opt.isSet(OFFSET))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_offset");
@@ -412,6 +479,8 @@ void set_config_states(std::string command)
         gdk_color_parse (scolor.c_str(), &rgb);
         gtk_color_button_set_color (GTK_COLOR_BUTTON (color), &rgb);
     }
+
+    if (argc > 0) delete[] argv;
 }
 
 void set_signals()
@@ -671,7 +740,7 @@ void on_settings_delete()
 void on_settings_update()
 {
     Config config;
-    std::string filename = config.getFile();
+    std::string filename = configFile.empty() ? config.getFile() : configFile;
     std::ofstream file(filename.c_str());
 
     if (!file.is_open())
@@ -680,7 +749,7 @@ void on_settings_update()
                                   GTK_DIALOG_DESTROY_WITH_PARENT,
                                   GTK_MESSAGE_ERROR,
                                   GTK_BUTTONS_OK,
-                                  (_("Error save config in ") + filename).c_str());
+                                  "%s",(_("Error save config in ") + filename).c_str());
 
         gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
@@ -739,6 +808,14 @@ void on_settings_update()
     file.close();
 
     Run run;
+
+    if (!configFile.empty())
+    {
+        fullcommand = PACKAGE_NAME;
+        fullcommand += " --config ";
+        fullcommand += configFile;
+    }
+
     run.restart(fullcommand);
 }
 
@@ -804,6 +881,13 @@ std::string getCommand()
         }
     }
 
+    checkbutton = glade_xml_get_widget (xml, "checkbutton_grow");
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
+    {
+        command += " --grow";
+    }
+
     checkbutton = glade_xml_get_widget (xml, "checkbutton_offset");
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
