@@ -6,11 +6,13 @@
 
 enum Options
 {
+    CONFIG,
     BPRESS,
     ABOVE_DESK,
     VBAR,
     NOFONT,
     POS,
+    GROW,
     ISIZE,
     IDIST,
     NANIM,
@@ -36,7 +38,8 @@ class OptParser
 
 	bool isSet(Options opt);
 	std::string getArg(Options opt);
-
+    char ** getArgv();
+        
     private:
     int argc;
     char **argv;
